/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#ifndef CAOSDB_INFO_H
#define CAOSDB_INFO_H
/**
 * @file caosdb/info.h
 * @author Timm Fitschen
 * @date 2021-07-02
 * @brief General information about the CaosDBServer.
 */
#include <cstdint>                        // for uint32_t
#include <string>                         // for string
#include "caosdb/info/v1alpha1/main.pb.h" // for VersionInfo

namespace caosdb::info {

using ProtoVersionInfo = caosdb::info::v1alpha1::VersionInfo;

/**
 * @brief Wrapper class for the VersionInfo protobuf.
 */
class VersionInfo {
private:
  ProtoVersionInfo *info;

public:
  explicit VersionInfo(ProtoVersionInfo *info);
  [[nodiscard]] auto GetMajor() const -> uint32_t;
  [[nodiscard]] auto GetMinor() const -> uint32_t;
  [[nodiscard]] auto GetPatch() const -> uint32_t;
  [[nodiscard]] auto GetPreRelease() const -> const std::string &;
  [[nodiscard]] auto GetBuild() const -> const std::string &;
};

} // namespace caosdb::info
#endif
